==> am_mod_lbr_0_1_0.tar.tgz: am_module_library/components/lbr/template/barnraiser_01/overview.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>


<div class="col_left1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_latest_sets'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($sets)) {
				?>
				<table border="0" cellspacing="0" cellpadding="2" width="100%">
				<?php
				foreach($sets as $key => $i):
				?>
				<tr>
					<td width="32">
						<a href="index.php?amn=lbr_page&amp;set_id=<?php echo $i['set_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file_md5_name_view'];?>" border="0" alt="<?php echo $i['image']['file_title'];?>" /></a><br />
					</td>
					<td>
						<a href="index.php?amn=lbr_page&amp;set_id=<?php echo $i['set_id'];?>"><b><?php echo $i['set_title'];?></b></a><br />
						<?php echo $i['set_synopsis'];?>
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				<?php
				} else {
				?>
					<p>
						<?php echo $lang['template_error']['err_no_items'];?><br />
					</p>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_tied_revisions'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($tied_revisions)) {
				?>
				<table border="0" cellspacing="2" cellpadding="2" width="100%">
				<?php
				foreach($tied_revisions as $key => $i):
				?>
				<tr>
					<td valign="top" colspan="3">
						<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['library'];?>&amp;set_id=<?php echo $i['item_id'];?>&amp;identity_id=<?php echo $i['identity']['identity_id'];?>"><b><?php echo $i['identity']['identity_nic'];?></b></a><br />
					</td>
				</tr>
				<tr>
					<td width="32">
						<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['library'];?>&amp;set_id=<?php echo $i['item_id'];?>&amp;identity_id=<?php echo $i['identity_id_relation'];?>"><img src="get_file.php?file=<?php echo $i['identity']['image']['file_md5_name_view'];?>" border="0" alt="<?php echo $i['identity']['image']['file_title'];?>" /></a><br />
					</td>
					<?php
					if (!empty($i['revision'])) {
					?>
					<td valign="top">
						<a href="index.php?amn=lbr_page&amp;set_id=<?php echo $i['item_id'];?>&amp;revision_id=<?php echo $i['revision']['revision_id'];?>"><?php echo $i['revision']['page_title'];?></a><br />
					</td>
					<td align="right" valign="top">
						<?php echo $this->date->formatDate($i['revision']['revision_create_datetime'],1);?><br />
					</td>
					<?php
					}
					else {
					?>
					<td colspan="2" valign="top">
						<?php echo $lang['txt_no_revisions'];?><br />
					</td>
					<?php }?>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				<?php
				} else {
				?>
					<p>
						<?php echo $lang['template_error']['err_no_items'];?><br />
					</p>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_latest_revisions'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($revisions)) {
				?>
				<table border="0" cellspacing="" cellpadding="2" width="100%">
				<?php
				foreach($revisions as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="index.php?amn=lbr_page&amp;page_id=<?php echo $i['page_id'];?>"><b><?php echo $i['page_title'];?></b></a><br />
						<?php echo $i['page_synopsis'];?>
					</td>
					<td align="right" valign="top">
						<?php echo $this->date->formatDate($i['revision_create_datetime'],1);?><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				<?php
				} else {
				?>
					<p>
						<?php echo $lang['template_error']['err_no_items'];?><br />
					</p>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>

<div class="col_right1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_wiki'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<?php echo $lang['txt_wiki_intro'];?><br />
				</p>
			</div>
		</div>
	</div>
	
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
	
	<?php
	if (isset($my_sets)) {
	?>
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_my_sets'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<table border="0" cellspacing="0" cellpadding="2" width="100%">
				<?php
				foreach($my_sets as $key => $i):
				?>
				<tr>
					<td width="32">
						<a href="index.php?amn=lbr_page&amp;page_id=<?php echo $i['default_page_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file_md5_name_view'];?>&amp;type=<?php echo $i['image']['type']; ?>&amp;directory=<?php echo $i['image']['directory']."/"; ?>" border="0" alt="<?php echo $i['image']['file_title'];?>" /></a><br />
					</td>
					<td>
						<a href="index.php?amn=lbr_page&amp;page_id=<?php echo $i['default_page_id'];?>"><b><?php echo $i['set_title'];?></b></a><br />
						<?php echo $i['set_synopsis'];?>
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
			</div>
		</div>
	</div>
	
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
	<?php }?>
	
	
	<?php
	if (isset($my_bookmarks)) {
	?>
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_favourites'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<b><?php echo $lang['txt_bookmarked'];?></b><br />
				</p>
				
				<p>
					<?php
					foreach($my_bookmarks as $key => $i):
					?>
					<a href="index.php?amn=lbr_page&amp;page_id=<?php echo $i['page_id'];?>"><?php echo $i['page_title'];?></a><br />
					<?php
					endforeach;
					?>
				</p>
			</div>
		</div>
	</div>
		
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
	<?php }?>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_tied_comments'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($tied_comments)) {
				?>
				<table border="0" cellspacing="" cellpadding="2" width="100%">
				<?php
				foreach($tied_comments as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="index.php?amn=lbr_page&amp;page_id=<?php echo $i['inner_item_id'];?>#comment_id<?php echo $i['comment_id'];?>"><b><?php echo $i['identity']['identity_nic'];?></b></a><br />
						<?php echo $i['comment_body'];?>
					</td>
					<td align="right" valign="top">
						<?php echo $this->date->formatDate($i['comment_create_datetime'],1);?><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				<?php
				} else {
				?>
					<p>
						<?php echo $lang['template_error']['err_no_items'];?><br />
					</p>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
	
</div>
</form>

==> am_mod_lbr_0_2.tar.tgz: am_module_library/components/lbr/template/barnraiser_01/overview.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>


<div class="col_left1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_latest_sets'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($sets)) {
				?>
				<table border="0" cellspacing="0" cellpadding="2" width="100%">
				<?php
				foreach($sets as $key => $i):
				?>
				<tr>
					<td width="32">
						<a href="index.php?amn=lbr_page&amp;set_id=<?php echo $i['set_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file_md5_name_view'];?>" border="0" alt="<?php echo $i['image']['file_title'];?>" /></a><br />
					</td>
					<td>
						<a href="index.php?amn=lbr_page&amp;set_id=<?php echo $i['set_id'];?>"><b><?php echo $i['set_title'];?></b></a><br />
						<?php echo $i['set_synopsis'];?>
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				<?php
				} else {
				?>
					<p>
						<?php echo $lang['template_error']['err_no_items'];?><br />
					</p>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_tied_revisions'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($tied_revisions)) {
				?>
				<table border="0" cellspacing="2" cellpadding="2" width="100%">
				<?php
				foreach($tied_revisions as $key => $i):
				?>
				<tr>
					<td valign="top" colspan="3">
						<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['library'];?>&amp;set_id=<?php echo $i['item_id'];?>&amp;identity_id=<?php echo $i['identity']['identity_id'];?>"><b><?php echo $i['identity']['identity_nic'];?></b></a><br />
					</td>
				</tr>
				<tr>
					<td width="32">
						<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['library'];?>&amp;set_id=<?php echo $i['item_id'];?>&amp;identity_id=<?php echo $i['identity_id_relation'];?>"><img src="get_file.php?file=<?php echo $i['identity']['image']['file_md5_name_view'];?>" border="0" alt="<?php echo $i['identity']['image']['file_title'];?>" /></a><br />
					</td>
					<?php
					if (!empty($i['revision'])) {
					?>
					<td valign="top">
						<a href="index.php?amn=lbr_page&amp;set_id=<?php echo $i['item_id'];?>&amp;revision_id=<?php echo $i['revision']['revision_id'];?>"><?php echo $i['revision']['page_title'];?></a><br />
					</td>
					<td align="right" valign="top">
						<?php echo $this->date->formatDate($i['revision']['revision_create_datetime'],1);?><br />
					</td>
					<?php
					}
					else {
					?>
					<td colspan="2" valign="top">
						<?php echo $lang['txt_no_revisions'];?><br />
					</td>
					<?php }?>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				<?php
				} else {
				?>
					<p>
						<?php echo $lang['template_error']['err_no_items'];?><br />
					</p>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_latest_revisions'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($revisions)) {
				?>
				<table border="0" cellspacing="" cellpadding="2" width="100%">
				<?php
				foreach($revisions as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="index.php?amn=lbr_page&amp;page_id=<?php echo $i['page_id'];?>"><b><?php echo $i['page_title'];?></b></a><br />
						<?php echo $i['page_synopsis'];?>
					</td>
					<td align="right" valign="top">
						<?php echo $this->date->formatDate($i['revision_create_datetime'],1);?><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				<?php
				} else {
				?>
					<p>
						<?php echo $lang['template_error']['err_no_items'];?><br />
					</p>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>

<div class="col_right1">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_wiki'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<?php echo $lang['txt_wiki_intro'];?><br />
				</p>
			</div>
		</div>
	</div>
	
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
	
	<?php
	if (isset($my_sets)) {
	?>
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_my_sets'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<table border="0" cellspacing="0" cellpadding="2" width="100%">
				<?php
				foreach($my_sets as $key => $i):
				?>
				<tr>
					<td width="32">
						<a href="index.php?amn=lbr_page&amp;set_id=<?php echo $i['set_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file_md5_name_view'];?>&amp;type=<?php echo $i['image']['type']; ?>&amp;directory=<?php echo $i['image']['directory']."/"; ?>" border="0" alt="<?php echo $i['image']['file_title'];?>" /></a><br />
					</td>
					<td>
						<a href="index.php?amn=lbr_page&amp;set_id=<?php echo $i['set_id'];?>"><b><?php echo $i['set_title'];?></b></a><br />
						<?php echo $i['set_synopsis'];?>
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
			</div>
		</div>
	</div>
	
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
	<?php }?>
	
	
	<?php
	if (isset($my_bookmarks)) {
	?>
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_favourites'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<b><?php echo $lang['txt_bookmarked'];?></b><br />
				</p>
				
				<p>
					<?php
					foreach($my_bookmarks as $key => $i):
					?>
					<a href="index.php?amn=lbr_page&amp;page_id=<?php echo $i['page_id'];?>"><?php echo $i['page_title'];?></a><br />
					<?php
					endforeach;
					?>
				</p>
			</div>
		</div>
	</div>
		
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
	<?php }?>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_tied_comments'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($tied_comments)) {
				?>
				<table border="0" cellspacing="" cellpadding="2" width="100%">
				<?php
				foreach($tied_comments as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="index.php?amn=lbr_page&amp;revision_id=<?php echo $i['inner_item_revision'];?>#comment_id<?php echo $i['comment_id'];?>"><b><?php echo $i['identity']['identity_nic'];?></b></a><br />
						<?php echo $i['comment_body'];?>
					</td>
					<td align="right" valign="top">
						<?php echo $this->date->formatDate($i['comment_create_datetime'],1);?><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				<?php
				} else {
				?>
					<p>
						<?php echo $lang['template_error']['err_no_items'];?><br />
					</p>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
	
</div>
</form>
